.. Interactive Figure documentation master file, created by
   sphinx-quickstart on Fri Dec 15 13:55:40 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Interactive Figure's documentation!
==============================================

.. toctree::
   :maxdepth: 2